"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = __importDefault(require("path"));
var shared_1 = require("./shared");
var cosmosConfigPath_1 = require("./cosmosConfigPath");
var resolve_1 = require("./resolve");
function createCosmosConfig(cosmosConfigInput) {
    if (cosmosConfigInput === void 0) { cosmosConfigInput = {}; }
    var cosmosConfigPath = cosmosConfigPath_1.getCosmosConfigPath();
    var rootDir = getRootDir(cosmosConfigInput, cosmosConfigPath);
    return __assign({}, cosmosConfigInput, { rootDir: rootDir, exportPath: getExportPath(cosmosConfigInput, rootDir), staticPath: getStaticPath(cosmosConfigInput, rootDir), publicUrl: getPublicUrl(cosmosConfigInput), fixturesDir: getFixturesDir(cosmosConfigInput), fixtureFileSuffix: getFixtureFileSuffix(cosmosConfigInput), watchDirs: getWatchDirs(cosmosConfigInput, rootDir), userDepsFilePath: getUserDepsFilePath(cosmosConfigInput, rootDir), hostname: getHostname(cosmosConfigInput), port: getPort(cosmosConfigInput), globalImports: getGlobalImports(cosmosConfigInput, rootDir), ui: cosmosConfigInput.ui || {} });
}
exports.createCosmosConfig = createCosmosConfig;
function getRootDir(_a, cosmosConfigPath) {
    var rootDir = _a.rootDir;
    var cliArgs = shared_1.getCliArgs();
    if (typeof cliArgs.rootDir === 'string') {
        return shared_1.getRootDirAtPath(cliArgs.rootDir);
    }
    var configDir = path_1.default.dirname(cosmosConfigPath);
    return rootDir ? path_1.default.resolve(configDir, rootDir) : configDir;
}
function getExportPath(cosmosConfigInput, rootDir) {
    var _a = cosmosConfigInput.exportPath, exportPath = _a === void 0 ? 'cosmos-export' : _a;
    return resolve_1.resolvePath(rootDir, exportPath);
}
function getStaticPath(cosmosConfigInput, rootDir) {
    var _a = cosmosConfigInput.staticPath, staticPath = _a === void 0 ? null : _a;
    return staticPath && resolve_1.resolvePath(rootDir, staticPath);
}
function getPublicUrl(_a) {
    var _b = _a.publicUrl, publicUrl = _b === void 0 ? '/' : _b;
    return publicUrl;
}
function getFixturesDir(_a) {
    var _b = _a.fixturesDir, fixturesDir = _b === void 0 ? '__fixtures__' : _b;
    return fixturesDir;
}
function getFixtureFileSuffix(_a) {
    var _b = _a.fixtureFileSuffix, fixtureFileSuffix = _b === void 0 ? 'fixture' : _b;
    return fixtureFileSuffix;
}
function getWatchDirs(cosmosConfigInput, rootDir) {
    var _a = cosmosConfigInput.watchDirs, watchDirs = _a === void 0 ? ['.'] : _a;
    return watchDirs.map(function (watchDir) { return resolve_1.resolvePath(rootDir, watchDir); });
}
function getUserDepsFilePath(cosmosConfigInput, rootDir) {
    var _a = cosmosConfigInput.userDepsFilePath, userDepsFilePath = _a === void 0 ? 'cosmos.userdeps.js' : _a;
    return resolve_1.resolvePath(rootDir, userDepsFilePath);
}
function getHostname(_a) {
    var _b = _a.hostname, hostname = _b === void 0 ? null : _b;
    return hostname;
}
function getPort(cosmosConfigInput) {
    var cliArgs = shared_1.getCliArgs();
    if (typeof cliArgs.port === 'number') {
        return cliArgs.port;
    }
    var _a = cosmosConfigInput.port, port = _a === void 0 ? 5000 : _a;
    return port;
}
function getGlobalImports(cosmosConfigInput, rootDir) {
    var _a = cosmosConfigInput.globalImports, globalImports = _a === void 0 ? [] : _a;
    return globalImports.map(function (globalImport) {
        return resolve_1.resolveModule(rootDir, globalImport);
    });
}
