"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs_1 = __importDefault(require("fs"));
var path_1 = __importDefault(require("path"));
var launch_editor_1 = __importDefault(require("launch-editor"));
function openFile(_a) {
    var cosmosConfig = _a.cosmosConfig, expressApp = _a.expressApp;
    expressApp.get('/_open', function (req, res) {
        var _a = getReqQuery(req), filePath = _a.filePath, line = _a.line, column = _a.column;
        if (!filePath) {
            res.status(400).send("File path missing");
            return;
        }
        var absFilePath = resolveFilePath(cosmosConfig, filePath);
        if (!fs_1.default.existsSync(absFilePath)) {
            res.status(404).send("File not found at path: " + absFilePath);
            return;
        }
        launch_editor_1.default(absFilePath + ":" + line + ":" + column);
        res.send();
    });
}
exports.openFile = openFile;
function getReqQuery(req) {
    var filePath = req.query.filePath;
    var line = req.query.line ? parseInt(req.query.line, 10) : 1;
    var column = req.query.column ? parseInt(req.query.column, 10) : 1;
    return { filePath: filePath, line: line, column: column };
}
function resolveFilePath(cosmosConfig, filePath) {
    // This heuristic is needed because the open file endpoint is used for
    // multiple applications, which provide different file path types:
    // 1. Edit fixture button: Sends path relative to Cosmos rootDir
    // 2. react-error-overlay runtime error: Sends absolute path
    // 3. react-error-overlay compile error: Sends path relative to CWD
    if (path_1.default.isAbsolute(filePath)) {
        return filePath;
    }
    var cosmosRelPath = path_1.default.join(cosmosConfig.rootDir, filePath);
    var cwdRelPath = path_1.default.join(process.cwd(), filePath);
    return fs_1.default.existsSync(cosmosRelPath) ? cosmosRelPath : cwdRelPath;
}
