"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = __importDefault(require("path"));
var config_1 = require("../../../config");
var fs_1 = require("../../../shared/fs");
function createWebpackCosmosConfig(cosmosConfig) {
    var rootDir = cosmosConfig.rootDir;
    var configInput = (cosmosConfig.webpack || {});
    return {
        configPath: getWebpackConfigPath(configInput, rootDir),
        overridePath: getWebpackOverridePath(configInput, rootDir),
        hotReload: getHotReload(configInput)
    };
}
exports.createWebpackCosmosConfig = createWebpackCosmosConfig;
function getWebpackConfigPath(_a, rootDir) {
    var configPath = _a.configPath;
    if (typeof configPath === 'undefined') {
        return config_1.resolveModule(rootDir, 'webpack.config.js');
    }
    // User can choose to prevent automatical use of an existing webpack.config.js
    // file (relative to the root dir) by setting configPath to null
    if (!configPath) {
        return null;
    }
    var absPath = config_1.resolveModule(rootDir, configPath);
    if (!fs_1.fileExists(absPath)) {
        var relPath = path_1.default.relative(process.cwd(), absPath);
        throw new Error("webpack config not found at path: " + relPath);
    }
    return absPath;
}
function getWebpackOverridePath(_a, rootDir) {
    var overridePath = _a.overridePath;
    if (typeof overridePath === 'undefined') {
        return config_1.resolveModule(rootDir, 'webpack.override.js');
    }
    // User can choose to prevent automatical use of an existing webpack.override.js
    // file (relative to the root dir) by setting overridePath to null
    if (!overridePath) {
        return null;
    }
    var absPath = config_1.resolveModule(rootDir, overridePath);
    if (!fs_1.fileExists(absPath)) {
        var relPath = path_1.default.relative(process.cwd(), absPath);
        throw new Error("webpack override module not found at path: " + relPath);
    }
    return absPath;
}
function getHotReload(_a) {
    var _b = _a.hotReload, hotReload = _b === void 0 ? true : _b;
    return hotReload;
}
