"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var resolve_from_1 = __importDefault(require("resolve-from"));
var playgroundHtml_1 = require("../../../shared/playgroundHtml");
var shared_1 = require("./shared");
var htmlPlugin_1 = require("./htmlPlugin");
// This config doesn't have entry and output set up because it's not meant to
// work standalone. An entry & output will be added to this base config.
function getDefaultWebpackConfig(userWebpack, rootDir) {
    // react-cosmos doesn't directly depend on any webpack loader.
    // Instead, it includes the ones already installed by the user.
    var tsLoaderPath = resolve_from_1.default.silent(rootDir, 'ts-loader');
    var babelLoaderPath = resolve_from_1.default.silent(rootDir, 'babel-loader');
    var styleLoaderPath = resolve_from_1.default.silent(rootDir, 'style-loader');
    var cssLoaderPath = resolve_from_1.default.silent(rootDir, 'css-loader');
    // Note: Since webpack >= v2.0.0, importing of JSON files will work by default
    var jsonLoaderPath = resolve_from_1.default.silent(rootDir, 'json-loader');
    var rules = [];
    var plugins = [];
    if (tsLoaderPath) {
        rules.push({
            test: /\.tsx?$/,
            loader: tsLoaderPath
        });
    }
    if (babelLoaderPath) {
        rules.push({
            test: /\.jsx?$/,
            exclude: /node_modules/,
            use: {
                loader: babelLoaderPath,
                options: {
                    root: rootDir
                }
            }
        });
    }
    if (styleLoaderPath && cssLoaderPath) {
        rules.push({
            test: /\.css$/,
            loader: cssLoaderPath
                ? styleLoaderPath + "!" + cssLoaderPath
                : styleLoaderPath,
            exclude: /node_modules/
        });
        // Preprocess 3rd party .css files located in node_modules
        rules.push({
            test: /\.css$/,
            loader: cssLoaderPath
                ? styleLoaderPath + "!" + cssLoaderPath
                : styleLoaderPath,
            include: /node_modules/
        });
    }
    if (jsonLoaderPath) {
        rules.push({
            test: /\.json$/,
            loader: jsonLoaderPath,
            exclude: /node_modules/
        });
    }
    var htmlWebpackPlugin = htmlPlugin_1.getHtmlWebpackPlugin(rootDir);
    if (htmlWebpackPlugin) {
        plugins.push(new htmlWebpackPlugin({
            title: 'React Cosmos',
            filename: playgroundHtml_1.RENDERER_FILENAME
        }));
    }
    var config = {
        // Besides other advantages, cheap-module-source-map is compatible with
        // React.componentDidCatch https://github.com/facebook/react/issues/10441
        devtool: 'cheap-module-source-map',
        resolve: {
            // Warning: webpack 1.x expects ['', '.js', '.jsx']
            extensions: ['.js', '.jsx']
        },
        module: {
            // Note: `module.rules` only works with webpack >=2.x. For 1.x
            // compatibility a custom webpack config (with module.loaders) is required
            rules: rules
        },
        plugins: plugins
    };
    var webpack4 = userWebpack.version && parseInt(userWebpack.version, 10) >= 4;
    if (!webpack4) {
        return config;
    }
    return __assign({}, config, { mode: shared_1.getNodeEnv(), optimization: {
            // Cosmos reads component names at run-time, so it is crucial to not
            // minify even when building with production env (ie. when exporting)
            // https://github.com/react-cosmos/react-cosmos/issues/701
            minimize: false
        } });
}
exports.getDefaultWebpackConfig = getDefaultWebpackConfig;
