"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = __importDefault(require("path"));
var webpack_1 = require("../cosmosConfig/webpack");
var shared_1 = require("./shared");
var htmlPlugin_1 = require("./htmlPlugin");
function getDevWebpackConfig(cosmosConfig, userWebpack) {
    var baseWebpackConfig = shared_1.getUserWebpackConfig(cosmosConfig, userWebpack);
    return __assign({}, baseWebpackConfig, { entry: getEntry(cosmosConfig), output: getOutput(cosmosConfig), module: __assign({}, baseWebpackConfig.module, { rules: getRules(baseWebpackConfig) }), plugins: getPlugins(cosmosConfig, baseWebpackConfig, userWebpack) });
}
exports.getDevWebpackConfig = getDevWebpackConfig;
function getEntry(cosmosConfig) {
    var hotReload = webpack_1.createWebpackCosmosConfig(cosmosConfig).hotReload;
    // The React devtools hook needs to be imported before any other module that
    // might import React
    var devtoolsHook = shared_1.resolveDomRendererPath('reactDevtoolsHook');
    var clientIndex = shared_1.resolveClientPath('index');
    return hotReload
        ? [devtoolsHook, getHotMiddlewareEntry(), clientIndex]
        : [devtoolsHook, clientIndex];
}
function getOutput(_a) {
    var publicUrl = _a.publicUrl;
    var filename = '[name].js';
    return {
        // Setting path to `/` in development (where files are saved in memory and
        // not on disk) is a weird required for old webpack versions
        path: '/',
        filename: filename,
        publicPath: publicUrl,
        // Enable click-to-open source in react-error-overlay
        devtoolModuleFilenameTemplate: function (info) {
            return path_1.default.resolve(info.absoluteResourcePath).replace(/\\/g, '/');
        }
    };
}
function getRules(baseWebpackConfig) {
    var existingRules = (baseWebpackConfig.module && baseWebpackConfig.module.rules) || [];
    return existingRules.concat([shared_1.getUserDepsLoaderRule()]);
}
function getPlugins(cosmosConfig, baseWebpackConfig, userWebpack) {
    var existingPlugins = baseWebpackConfig.plugins || [];
    var globalsPlugin = shared_1.getGlobalsPlugin(cosmosConfig, userWebpack, true);
    var noEmitErrorsPlugin = new userWebpack.NoEmitOnErrorsPlugin();
    var plugins = existingPlugins.concat([globalsPlugin, noEmitErrorsPlugin]);
    var hotReload = webpack_1.createWebpackCosmosConfig(cosmosConfig).hotReload;
    if (hotReload && !shared_1.hasPlugin(plugins, 'HotModuleReplacementPlugin')) {
        var hmrPlugin = new userWebpack.HotModuleReplacementPlugin();
        plugins = plugins.concat([hmrPlugin]);
    }
    return htmlPlugin_1.ensureHtmlWebackPlugin(cosmosConfig, plugins);
}
function getHotMiddlewareEntry() {
    var clientPath = require.resolve('webpack-hot-middleware/client');
    return clientPath + "?reload=true&overlay=false";
}
