"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = __importDefault(require("path"));
var yargs_1 = require("yargs");
var fs_1 = require("../../../shared/fs");
var webpack_1 = require("../cosmosConfig/webpack");
var default_1 = require("./default");
var module_1 = require("./module");
function getUserWebpackConfig(cosmosConfig, userWebpack) {
    var baseWebpackConfig = getBaseWebpackConfig(cosmosConfig, userWebpack);
    var overridePath = webpack_1.createWebpackCosmosConfig(cosmosConfig).overridePath;
    if (!overridePath || !fs_1.moduleExists(overridePath)) {
        return baseWebpackConfig;
    }
    var relPath = path_1.default.relative(process.cwd(), overridePath);
    console.log("[Cosmos] Overriding webpack config at " + relPath);
    var webpackOverride = module_1.getDefaultExport(fs_1.requireModule(overridePath));
    return webpackOverride(baseWebpackConfig, getNodeEnv());
}
exports.getUserWebpackConfig = getUserWebpackConfig;
function getBaseWebpackConfig(cosmosConfig, userWebpack) {
    var rootDir = cosmosConfig.rootDir;
    var configPath = webpack_1.createWebpackCosmosConfig(cosmosConfig).configPath;
    if (!configPath || !fs_1.moduleExists(configPath)) {
        console.log('[Cosmos] Using default webpack config');
        return default_1.getDefaultWebpackConfig(userWebpack, rootDir);
    }
    var relPath = path_1.default.relative(process.cwd(), configPath);
    console.log("[Cosmos] Using webpack config found at " + relPath);
    var userConfigExport = module_1.getDefaultExport(fs_1.requireModule(configPath));
    return typeof userConfigExport === 'function'
        ? userConfigExport(yargs_1.argv.env || getNodeEnv(), yargs_1.argv)
        : userConfigExport;
}
exports.getBaseWebpackConfig = getBaseWebpackConfig;
function resolveDomRendererPath(relPath) {
    return require.resolve("../../../domRenderer/" + relPath);
}
exports.resolveDomRendererPath = resolveDomRendererPath;
function resolveClientPath(relPath) {
    return require.resolve("../client/" + relPath);
}
exports.resolveClientPath = resolveClientPath;
function getUserDepsLoaderRule() {
    return {
        loader: require.resolve('./userDepsLoader'),
        include: resolveClientPath('userDeps')
    };
}
exports.getUserDepsLoaderRule = getUserDepsLoaderRule;
function getGlobalsPlugin(_a, userWebpack, devServerOn) {
    var publicUrl = _a.publicUrl;
    var cleanPublicUrl = removeTrailingSlash(publicUrl);
    return new userWebpack.DefinePlugin({
        // "if (__DEV__)" blocks get stripped when compiling a static export build
        __DEV__: JSON.stringify(devServerOn),
        'process.env': {
            NODE_ENV: JSON.stringify(getNodeEnv()),
            PUBLIC_URL: JSON.stringify(cleanPublicUrl)
        }
    });
}
exports.getGlobalsPlugin = getGlobalsPlugin;
function hasPlugin(plugins, pluginName) {
    return (plugins && plugins.filter(function (p) { return isInstanceOfPlugin(p, pluginName); }).length > 0);
}
exports.hasPlugin = hasPlugin;
function isInstanceOfPlugin(plugin, constructorName) {
    return plugin.constructor && plugin.constructor.name === constructorName;
}
exports.isInstanceOfPlugin = isInstanceOfPlugin;
function removeTrailingSlash(url) {
    return url.replace(/\/$/, '');
}
function getNodeEnv() {
    // Disallow non dev/prod environments, like "test" inside Jest, because
    // they are not supported by webpack
    return process.env.NODE_ENV === 'production' ? 'production' : 'development';
}
exports.getNodeEnv = getNodeEnv;
