"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs_1 = __importDefault(require("fs"));
var shared_1 = require("./shared");
var slash_1 = require("./slash");
var static_1 = require("./static");
exports.RENDERER_FILENAME = '_renderer.html';
function getDevPlaygroundHtml(platformType, cosmosConfig) {
    var ui = cosmosConfig.ui;
    return getPlaygroundHtml(__assign({}, ui, { core: getDevCoreConfig(platformType, cosmosConfig) }));
}
exports.getDevPlaygroundHtml = getDevPlaygroundHtml;
function getExportPlaygroundHtml(cosmosConfig) {
    var ui = cosmosConfig.ui;
    return getPlaygroundHtml(__assign({}, ui, { core: getExportCoreConfig(cosmosConfig) }));
}
exports.getExportPlaygroundHtml = getExportPlaygroundHtml;
function getDevCoreConfig(platformType, cosmosConfig) {
    switch (platformType) {
        case 'native':
            return __assign({}, getSharedCoreConfig(cosmosConfig), { devServerOn: true, webRendererUrl: null });
        case 'web':
            return __assign({}, getSharedCoreConfig(cosmosConfig), { devServerOn: true, webRendererUrl: getWebRendererUrl(cosmosConfig) });
        default:
            throw new Error("Invalid platform type: " + platformType);
    }
}
function getExportCoreConfig(cosmosConfig) {
    return __assign({}, getSharedCoreConfig(cosmosConfig), { devServerOn: false, webRendererUrl: getWebRendererUrl(cosmosConfig) });
}
function getSharedCoreConfig(cosmosConfig) {
    var rootDir = cosmosConfig.rootDir, fixturesDir = cosmosConfig.fixturesDir, fixtureFileSuffix = cosmosConfig.fixtureFileSuffix;
    return { projectId: rootDir, fixturesDir: fixturesDir, fixtureFileSuffix: fixtureFileSuffix };
}
function getWebRendererUrl(_a) {
    var publicUrl = _a.publicUrl;
    return slash_1.slash(publicUrl, exports.RENDERER_FILENAME);
}
function getPlaygroundHtml(playgroundConfig) {
    return shared_1.replaceKeys(getPlaygroundHtmlTemplate(), {
        __PLAYGROUND_CONFIG: JSON.stringify(playgroundConfig)
    });
}
function getPlaygroundHtmlTemplate() {
    return fs_1.default.readFileSync(static_1.getStaticPath('index.html'), 'utf8');
}
